# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/v1/lock_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/marketplace/licensemanager/v1/lock_service.proto',
  package='yandex.cloud.marketplace.licensemanager.v1',
  syntax='proto3',
  serialized_options=b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=yandex/cloud/marketplace/licensemanager/v1/lock_service.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\'\n\x0eGetLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x43reateLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x43reateLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"%\n\x12\x45nsureLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"*\n\x11\x44\x65leteLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x44\x65leteLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"[\n#GetLockByInstanceAndResourceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\x88\x08\n\x0bLockService\x12\xac\x01\n\x03Get\x12:.yandex.cloud.marketplace.licensemanager.v1.GetLockRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"7\x82\xd3\xe4\x93\x02\x31\x12//marketplace/license-manager/v1/locks/{lock_id}\x12\xe5\x01\n\x18GetByInstanceAndResource\x12O.yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"F\x82\xd3\xe4\x93\x02@\x12>/marketplace/license-manager/v1/locks:getByInstanceAndResource\x12\xba\x01\n\x06\x43reate\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"N\x82\xd3\xe4\x93\x02*\"%/marketplace/license-manager/v1/locks:\x01*\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x12\xcf\x01\n\x06\x45nsure\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\x01*\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x12\xd2\x01\n\x06\x44\x65lete\x12=.yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest\x1a!.yandex.cloud.operation.Operation\"f\x82\xd3\xe4\x93\x02\x31*//marketplace/license-manager/v1/locks/{lock_id}\xb2\xd2*+\n\x12\x44\x65leteLockMetadata\x12\x15google.protobuf.EmptyB\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOCKREQUEST = _descriptor.Descriptor(
  name='GetLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockRequest.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=338,
)


_CREATELOCKREQUEST = _descriptor.Descriptor(
  name='CreateLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=413,
)


_CREATELOCKMETADATA = _descriptor.Descriptor(
  name='CreateLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=452,
)


_ENSURELOCKMETADATA = _descriptor.Descriptor(
  name='EnsureLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=491,
)


_DELETELOCKREQUEST = _descriptor.Descriptor(
  name='DeleteLockRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=535,
)


_DELETELOCKMETADATA = _descriptor.Descriptor(
  name='DeleteLockMetadata',
  full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_id', full_name='yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata.lock_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=574,
)


_GETLOCKBYINSTANCEANDRESOURCEREQUEST = _descriptor.Descriptor(
  name='GetLockByInstanceAndResourceRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=667,
)

DESCRIPTOR.message_types_by_name['GetLockRequest'] = _GETLOCKREQUEST
DESCRIPTOR.message_types_by_name['CreateLockRequest'] = _CREATELOCKREQUEST
DESCRIPTOR.message_types_by_name['CreateLockMetadata'] = _CREATELOCKMETADATA
DESCRIPTOR.message_types_by_name['EnsureLockMetadata'] = _ENSURELOCKMETADATA
DESCRIPTOR.message_types_by_name['DeleteLockRequest'] = _DELETELOCKREQUEST
DESCRIPTOR.message_types_by_name['DeleteLockMetadata'] = _DELETELOCKMETADATA
DESCRIPTOR.message_types_by_name['GetLockByInstanceAndResourceRequest'] = _GETLOCKBYINSTANCEANDRESOURCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLockRequest = _reflection.GeneratedProtocolMessageType('GetLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.GetLockRequest)
  })
_sym_db.RegisterMessage(GetLockRequest)

CreateLockRequest = _reflection.GeneratedProtocolMessageType('CreateLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest)
  })
_sym_db.RegisterMessage(CreateLockRequest)

CreateLockMetadata = _reflection.GeneratedProtocolMessageType('CreateLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.CreateLockMetadata)
  })
_sym_db.RegisterMessage(CreateLockMetadata)

EnsureLockMetadata = _reflection.GeneratedProtocolMessageType('EnsureLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENSURELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.EnsureLockMetadata)
  })
_sym_db.RegisterMessage(EnsureLockMetadata)

DeleteLockRequest = _reflection.GeneratedProtocolMessageType('DeleteLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOCKREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest)
  })
_sym_db.RegisterMessage(DeleteLockRequest)

DeleteLockMetadata = _reflection.GeneratedProtocolMessageType('DeleteLockMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOCKMETADATA,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.DeleteLockMetadata)
  })
_sym_db.RegisterMessage(DeleteLockMetadata)

GetLockByInstanceAndResourceRequest = _reflection.GeneratedProtocolMessageType('GetLockByInstanceAndResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOCKBYINSTANCEANDRESOURCEREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest)
  })
_sym_db.RegisterMessage(GetLockByInstanceAndResourceRequest)


DESCRIPTOR._options = None
_GETLOCKREQUEST.fields_by_name['lock_id']._options = None
_CREATELOCKREQUEST.fields_by_name['instance_id']._options = None
_CREATELOCKREQUEST.fields_by_name['resource_id']._options = None
_DELETELOCKREQUEST.fields_by_name['lock_id']._options = None
_GETLOCKBYINSTANCEANDRESOURCEREQUEST.fields_by_name['instance_id']._options = None
_GETLOCKBYINSTANCEANDRESOURCEREQUEST.fields_by_name['resource_id']._options = None

_LOCKSERVICE = _descriptor.ServiceDescriptor(
  name='LockService',
  full_name='yandex.cloud.marketplace.licensemanager.v1.LockService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=670,
  serialized_end=1702,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOCKREQUEST,
    output_type=yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2._LOCK,
    serialized_options=b'\202\323\344\223\0021\022//marketplace/license-manager/v1/locks/{lock_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetByInstanceAndResource',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.GetByInstanceAndResource',
    index=1,
    containing_service=None,
    input_type=_GETLOCKBYINSTANCEANDRESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2._LOCK,
    serialized_options=b'\202\323\344\223\002@\022>/marketplace/license-manager/v1/locks:getByInstanceAndResource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002*\"%/marketplace/license-manager/v1/locks:\001*\262\322*\032\n\022CreateLockMetadata\022\004Lock',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Ensure',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Ensure',
    index=3,
    containing_service=None,
    input_type=_CREATELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\001*\262\322*\032\n\022CreateLockMetadata\022\004Lock',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.marketplace.licensemanager.v1.LockService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETELOCKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021*//marketplace/license-manager/v1/locks/{lock_id}\262\322*+\n\022DeleteLockMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOCKSERVICE)

DESCRIPTOR.services_by_name['LockService'] = _LOCKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v3/stt_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/stt/v3/stt_service.proto',
  package='speechkit.stt.v3',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/ai/stt/v3/stt_service.proto\x12\x10speechkit.stt.v3\x1a yandex/cloud/ai/stt/v3/stt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\";\n\x15GetRecognitionRequest\x12\"\n\x0coperation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502q\n\nRecognizer\x12\x63\n\x12RecognizeStreaming\x12\".speechkit.stt.v3.StreamingRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x00(\x01\x30\x01\x32\xb3\x02\n\x0f\x41syncRecognizer\x12\x9c\x01\n\rRecognizeFile\x12&.speechkit.stt.v3.RecognizeFileRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/stt/v3/recognizeFileAsync:\x01*\x12\x80\x01\n\x0eGetRecognition\x12\'.speechkit.stt.v3.GetRecognitionRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/stt/v3/getRecognition0\x01\x42\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_GETRECOGNITIONREQUEST = _descriptor.Descriptor(
  name='GetRecognitionRequest',
  full_name='speechkit.stt.v3.GetRecognitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='speechkit.stt.v3.GetRecognitionRequest.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=290,
)

DESCRIPTOR.message_types_by_name['GetRecognitionRequest'] = _GETRECOGNITIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRecognitionRequest = _reflection.GeneratedProtocolMessageType('GetRecognitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECOGNITIONREQUEST,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.GetRecognitionRequest)
  })
_sym_db.RegisterMessage(GetRecognitionRequest)


DESCRIPTOR._options = None
_GETRECOGNITIONREQUEST.fields_by_name['operation_id']._options = None

_RECOGNIZER = _descriptor.ServiceDescriptor(
  name='Recognizer',
  full_name='speechkit.stt.v3.Recognizer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=292,
  serialized_end=405,
  methods=[
  _descriptor.MethodDescriptor(
    name='RecognizeStreaming',
    full_name='speechkit.stt.v3.Recognizer.RecognizeStreaming',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._STREAMINGREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._STREAMINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOGNIZER)

DESCRIPTOR.services_by_name['Recognizer'] = _RECOGNIZER


_ASYNCRECOGNIZER = _descriptor.ServiceDescriptor(
  name='AsyncRecognizer',
  full_name='speechkit.stt.v3.AsyncRecognizer',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=408,
  serialized_end=715,
  methods=[
  _descriptor.MethodDescriptor(
    name='RecognizeFile',
    full_name='speechkit.stt.v3.AsyncRecognizer.RecognizeFile',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._RECOGNIZEFILEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/stt/v3/recognizeFileAsync:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecognition',
    full_name='speechkit.stt.v3.AsyncRecognizer.GetRecognition',
    index=1,
    containing_service=None,
    input_type=_GETRECOGNITIONREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._STREAMINGRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/stt/v3/getRecognition',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYNCRECOGNIZER)

DESCRIPTOR.services_by_name['AsyncRecognizer'] = _ASYNCRECOGNIZER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto',
  package='yandex.cloud.loadtesting.api.v1.agent',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCyandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a.yandex/cloud/compute/v1/instance_service.proto\x1a\x1dyandex/cloud/validation.proto\"\x9a\x05\n\x15\x43reateComputeInstance\x12\xa1\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12\\\n\x08metadata\x18\x08 \x03(\x0b\x32J.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry\x12G\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12U\n\x17network_interface_specs\x18\x0b \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\x05\x82\xc8\x31\x01\x31\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_CREATECOMPUTEINSTANCE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=807,
)

_CREATECOMPUTEINSTANCE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=856,
)

_CREATECOMPUTEINSTANCE = _descriptor.Descriptor(
  name='CreateComputeInstance',
  full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.labels', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.zone_id', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.resources_spec', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.metadata', index=3,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boot_disk_spec', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.boot_disk_spec', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_specs', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.network_interface_specs', index=5,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0011', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.service_account_id', index=6,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECOMPUTEINSTANCE_LABELSENTRY, _CREATECOMPUTEINSTANCE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=856,
)

_CREATECOMPUTEINSTANCE_LABELSENTRY.containing_type = _CREATECOMPUTEINSTANCE
_CREATECOMPUTEINSTANCE_METADATAENTRY.containing_type = _CREATECOMPUTEINSTANCE
_CREATECOMPUTEINSTANCE.fields_by_name['labels'].message_type = _CREATECOMPUTEINSTANCE_LABELSENTRY
_CREATECOMPUTEINSTANCE.fields_by_name['resources_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2._RESOURCESSPEC
_CREATECOMPUTEINSTANCE.fields_by_name['metadata'].message_type = _CREATECOMPUTEINSTANCE_METADATAENTRY
_CREATECOMPUTEINSTANCE.fields_by_name['boot_disk_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2._ATTACHEDDISKSPEC
_CREATECOMPUTEINSTANCE.fields_by_name['network_interface_specs'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2._NETWORKINTERFACESPEC
DESCRIPTOR.message_types_by_name['CreateComputeInstance'] = _CREATECOMPUTEINSTANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateComputeInstance = _reflection.GeneratedProtocolMessageType('CreateComputeInstance', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECOMPUTEINSTANCE_LABELSENTRY,
    '__module__' : 'yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECOMPUTEINSTANCE_METADATAENTRY,
    '__module__' : 'yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECOMPUTEINSTANCE,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance)
  })
_sym_db.RegisterMessage(CreateComputeInstance)
_sym_db.RegisterMessage(CreateComputeInstance.LabelsEntry)
_sym_db.RegisterMessage(CreateComputeInstance.MetadataEntry)


DESCRIPTOR._options = None
_CREATECOMPUTEINSTANCE_LABELSENTRY._options = None
_CREATECOMPUTEINSTANCE_METADATAENTRY._options = None
_CREATECOMPUTEINSTANCE.fields_by_name['labels']._options = None
_CREATECOMPUTEINSTANCE.fields_by_name['zone_id']._options = None
_CREATECOMPUTEINSTANCE.fields_by_name['resources_spec']._options = None
_CREATECOMPUTEINSTANCE.fields_by_name['boot_disk_spec']._options = None
_CREATECOMPUTEINSTANCE.fields_by_name['network_interface_specs']._options = None
# @@protoc_insertion_point(module_scope)
